@@ -2,9 +2,9 @@
 
 __author__ = """Ryan Scott"""
 __email__ = 'ryan.t.scott73@gmail.com'
-__version__ = '0.1.1'
+__version__ = '0.1.2'
 
-from razator_utils.razator_utils import *
-from razator_utils import *
+from razator_utils.razator_utils import batchify, camel_to_snake
+from razator_utils import log
 
 __all__ = ['batchify', 'camel_to_snake', 'log']
